package com.servicemall.basis.micro;

import com.alibaba.fastjson.JSONObject;
import com.servicemall.systemcommon.data.Constants;
import com.servicemall.systemcommon.data.ErrorEnum;
import com.servicemall.systemcommon.data.ValidCheckException;
import com.servicemall.systemcommon.util.JsonUtil;
import io.swagger.annotations.*;
import org.apache.ibatis.annotations.Param;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import team.bangbang.common.data.Pagination;
import team.bangbang.common.data.response.DataResponse;
import team.bangbang.common.data.response.ResponseBase;
import team.bangbang.common.net.http.HttpClient;
import team.bangbang.common.net.http.ResponseHandler;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 基础数据 - 微服务
 * @author 帮帮组
 * @version 1.0  2020-12-08
 */
@Api(tags = {"basis"})
@RestController
@CrossOrigin(allowCredentials = "true", allowedHeaders = "*", origins = "*", maxAge = 3600)
@RequestMapping(value = "/microservice/basis",produces="application/json;charset=UTF-8")
public final class BasisMicro {
    /**************************************************************************
     * ！！除非设计、指导人员有特别说明，否则此处不得随意增加、修改、删除！！
     * －－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－
     *
     *************************************************************************/

    /**
     * 省市接口
     */
    @ApiOperation(value = "获取省市信息", notes = "省市信息树形结构", httpMethod = "GET")
    @GetMapping(value = "/province")
    public ResponseBase province() {
        DataResponse<Object> result = new DataResponse<>();
        try {
            ResponseHandler responseHandler = new HttpClient().get("http://161.189.8.153:8889/v1/wx/provinces");
            result.setData(responseHandler.toJSONObject().getJSONArray("options"));

            return result;
        } catch (IOException e) {
            return new ResponseBase(ErrorEnum.E_405.getCode(), ErrorEnum.E_405.getMessage());
        } catch (ValidCheckException e) {
            return new ResponseBase(e.getCode(), e.getMessage());
        }
    }

    /**
     * 经销商接口
     */
    @ApiOperation(value = "获取经销商信息", notes = "经销商信息", httpMethod = "GET")
    @GetMapping(value = "/dealers")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", name = "pageNo", value = "分页参数 - 页号，默认为1", dataType = "int",defaultValue = "1",required = false),
            @ApiImplicitParam(paramType = "query", name = "pageSize", value = "分页参数 - 每页最大记录数量，默认为10", dataType = "int",defaultValue = "10",required = false)
    })
    public ResponseBase dealers(@RequestParam(defaultValue="1",required = false) Integer pageNo,@RequestParam(defaultValue="10",required = false) Integer pageSize) {
        DataResponse<Map<String, Object>> result = new DataResponse<>();

        try {
            ResponseHandler responseHandler = new HttpClient().get("http://161.189.8.153:8889/v1/wx/dealers");
            Map<String, Object> datas = new HashMap<String, Object>();
            JSONObject remoteJson=responseHandler.toJSONObject();
            datas.put("list", remoteJson.getJSONArray("rows"));
            JSONObject paginationJson=remoteJson.getJSONObject("pagination");
            Pagination pagination = new Pagination();
            pagination.setRecordCount(paginationJson.getIntValue("total"));
            pagination.setMaxResults(20);//每页条数，接口方默认20
            pagination.setPageNo(paginationJson.getIntValue("page"));
            datas.put("pagination", pagination);

            result.setData(datas);

            return result;
        } catch (IOException e) {
            return new ResponseBase(ErrorEnum.E_405.getCode(), ErrorEnum.E_405.getMessage());
        } catch (ValidCheckException e) {
            return new ResponseBase(e.getCode(), e.getMessage());
        }
    }

    /**
     * 车型车系接口
     */
    @ApiOperation(value = "获取车型车系信息", notes = "车型车系信息", httpMethod = "GET")
    @GetMapping(value = "/productManagement/getSeriesModels")
    public ResponseBase getSeriesModels() {
        DataResponse<Object> result = new DataResponse<>();
        try {
            ResponseHandler responseHandler = new HttpClient().get("http://161.189.8.153:8889/v1/product_management/get_series_models");
            result.setData(responseHandler.toJSONObject().get("data"));

            return result;
        } catch (IOException e) {
            return new ResponseBase(ErrorEnum.E_405.getCode(), ErrorEnum.E_405.getMessage());
        } catch (ValidCheckException e) {
            return new ResponseBase(e.getCode(), e.getMessage());
        }
    }

}
