package team.bangbang;

import com.servicemall.systemcommon.data.ErrorEnum;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import org.springframework.web.bind.annotation.RequestMethod;
import springfox.documentation.builders.ResponseMessageBuilder;
import springfox.documentation.schema.ModelRef;
import springfox.documentation.service.Contact;
import springfox.documentation.service.ResponseMessage;
import springfox.documentation.service.Tag;
import springfox.documentation.swagger2.annotations.EnableSwagger2;
import team.bangbang.common.config.Config;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Swagger2配置类
 * <p>
 * 在与spring boot集成时，放在与Application.java同级的目录下。
 * <p>
 * 通过@Configuration注解，让Spring来加载该类配置。
 * <p>
 * 再通过@EnableSwagger2注解来启用Swagger2。
 *
 * @author 帮帮组
 * @version 1.0 2018年10月13日
 */
@Configuration
@EnableSwagger2
public class Swagger2 {

    /**
     * 创建API应用 apiInfo() 增加API相关信息
     * 通过select()函数返回一个ApiSelectorBuilder实例,用来控制哪些接口暴露给Swagger来展现，
     * 本例采用指定扫描的包路径来定义指定要建立API的目录。
     *
     * @return
     */
    @Bean
    public Docket createRestApi() {

        //添加全局响应状态码
        List<ResponseMessage> responseMessageList = new ArrayList<>();
        Arrays.stream(ErrorEnum.values()).forEach(errorEnum -> {
            responseMessageList.add(
                    new ResponseMessageBuilder().code(errorEnum.getCode()).message(errorEnum.getMessage()).build()
            );
        });

        return new Docket(DocumentationType.SWAGGER_2)
                // 添加全局响应状态码
                .globalResponseMessage(RequestMethod.GET, responseMessageList)
                .globalResponseMessage(RequestMethod.POST, responseMessageList)
                .globalResponseMessage(RequestMethod.PUT, responseMessageList)
                .globalResponseMessage(RequestMethod.DELETE, responseMessageList)

                .apiInfo(apiInfo())
                .tags(new Tag("loyalty", "礼遇计划相关"), getTags())
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.servicemall")).paths(PathSelectors.any())
                .build();
    }

    private Tag[] getTags() {
        Tag[] tags = {
                new Tag("basis", "基础数据相关"),
                new Tag("car", "车辆相关"),
                new Tag("selected", "精选相关"),
                new Tag("right", "权益相关"),
                new Tag("slide", "轮播相关")

        };
        return tags;
    }

    /**
     * 创建该API的基本信息（这些基本信息会展现在文档页面中） 访问地址：http://项目实际地址/swagger-ui.html
     *
     * @return
     */
    private ApiInfo apiInfo() {
        return new ApiInfoBuilder()
                .title("ServiceMall 后端接口 APIs")
                .description("api根地址：http://49.234.59.211/")
                //.termsOfServiceUrl("http://49.234.59.211/")
                //.contact(new Contact("钱旺", "", ""))
                .version("1.0")
                .build();
    }
}
